@@ -30,6 +30,8 @@ cp tests/data/$BITNESS$ENDIAN/map/ccw_map-$BITNESS.ko \
    $MODULE_DIR
 gzip `find $MODULE_DIR -name '*.ko'`
 
+touch tests/tmp/empty
+
 # Expect no output.
 [ "`depmod`" = "" ]
 
@@ -114,7 +116,7 @@ diff -u $MODULE_DIR/modules.isapnpmap.old $MODULE_DIR/modules.isapnpmap
 diff -u $MODULE_DIR/modules.inputmap.old $MODULE_DIR/modules.inputmap
 diff -u $MODULE_DIR/modules.ofmap.old $MODULE_DIR/modules.ofmap
 
-[ "`depmod -e -A`" = "" ]
+[ "`depmod -e -F /empty -A`" = "" ]
 diff -u $MODULE_DIR/modules.dep.old $MODULE_DIR/modules.dep
 diff -u $MODULE_DIR/modules.pcimap.old $MODULE_DIR/modules.pcimap
 diff -u $MODULE_DIR/modules.usbmap.old $MODULE_DIR/modules.usbmap
@@ -124,7 +126,7 @@ diff -u $MODULE_DIR/modules.isapnpmap.old $MODULE_DIR/modules.isapnpmap
 diff -u $MODULE_DIR/modules.inputmap.old $MODULE_DIR/modules.inputmap
 diff -u $MODULE_DIR/modules.ofmap.old $MODULE_DIR/modules.ofmap
 
-[ "`depmod -e -A $MODTEST_VERSION`" = "" ]
+[ "`depmod -e -F /empty -A $MODTEST_VERSION`" = "" ]
 diff -u $MODULE_DIR/modules.dep.old $MODULE_DIR/modules.dep
 diff -u $MODULE_DIR/modules.pcimap.old $MODULE_DIR/modules.pcimap
 diff -u $MODULE_DIR/modules.usbmap.old $MODULE_DIR/modules.usbmap
@@ -147,7 +149,7 @@ diff -u tests/tmp/out tests/tmp/stdout
 depmod -n -a $MODTEST_VERSION | grep -v '^#' > $MODULE_DIR/modules.dep
 diff -u tests/tmp/out tests/tmp/stdout
 
-depmod -e -n -A $MODTEST_VERSION | grep -v '^#' > $MODULE_DIR/modules.dep
+depmod -e -F /empty -n -A $MODTEST_VERSION | grep -v '^#' > $MODULE_DIR/modules.dep
 diff -u tests/tmp/out tests/tmp/stdout
 
 done
